// @flow

import React from 'react'
import qs from 'querystring'
import cn from 'classnames'
import Script from 'react-load-script'

type TSocialToolbar = {
  className?: string,
  tag?: string,
  useColor?: boolean,
  text: string,
  url: string,
  items: { [key: string]: boolean | string },
  theme?: TTheme,
}

function SocialToolbar({
  className,
  tag: Component = 'div',
  useColor = false,
  text,
  url,
  items = {},
  theme = {},
  ...rest
}: TSocialToolbar) {
  const {
    email,
    facebook,
    googlePlus,
    linkedIn,
    pinterest,
    reddit,
    tumblr,
    twitter,
    whatsApp,
    xing,
    zalo,
  } =
    items || {}
  return (
    <Component
      {...rest}
      data-component="SocialToolbar"
      className={cn(className, theme.root)}
    >
      {email && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { email: useColor }, 'fa', email)}
          href={`mailto:?${qs.stringify({ subject: text, body: url })}`}
          target="_self"
          aria-label="Share by Email"
        />
      )}
      {facebook && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { facebook: useColor }, 'fa', facebook)}
          href={`https://facebook.com/sharer/sharer.php?u=${url}`}
          target="_blank"
          rel="noopener noreferrer"
          aria-label="Share on Facebook"
        />
      )}
      {googlePlus && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { google: useColor }, 'fa', googlePlus)}
          href={`https://plus.google.com/share?url=${url}`}
          target="_blank"
          rel="noopener noreferrer"
          aria-label="Share on Google+"
        />
      )}
      {linkedIn && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { linkedin: useColor }, 'fa', linkedIn)}
          href={`https://www.linkedin.com/shareArticle?${qs.stringify({
            mini: true,
            url,
            source: url,
            title: text,
            summary: text,
          })}`}
          target="_blank"
          rel="noopener noreferrer"
          aria-label="Share on LinkedIn"
        />
      )}
      {pinterest && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { pinterest: useColor }, 'fa', pinterest)}
          href={`https://pinterest.com/pin/create/button/?${qs.stringify({
            url,
            media: url,
            summary: text,
          })}`}
          target="_blank"
          rel="noopener noreferrer"
          aria-label="Share on Pinterest"
        />
      )}
      {reddit && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { reddit: useColor }, 'fa', reddit)}
          href={`https://reddit.com/submit/?url=${url}`}
          target="_blank"
          rel="noopener noreferrer"
          aria-label="Share on Reddit"
        />
      )}
      {tumblr && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { tumblr: useColor }, 'fa', tumblr)}
          href={`https://www.tumblr.com/widgets/share/tool?${qs.stringify({
            posttype: 'link',
            title: text,
            caption: text,
            content: url,
            canonicalUrl: url,
            shareSource: 'tumblr_share_button',
          })}`}
          target="_blank"
          rel="noopener noreferrer"
          aria-label="Share on Tumblr"
        />
      )}
      {twitter && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { twitter: useColor }, 'fa', twitter)}
          href={`https://twitter.com/intent/tweet/?&${qs.stringify({
            text,
            url,
          })}`}
          target="_blank"
          rel="noopener noreferrer"
          aria-label="Share on Twitter"
        />
      )}
      {whatsApp && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { whatsapp: useColor }, 'fa', whatsApp)}
          href={`whatsapp://send?text=${text ? `${text} ` : ''}${url}`}
          target="_blank"
          rel="noopener noreferrer"
          aria-label="Share on WhatsApp"
        />
      )}
      {xing && (
        <a // eslint-disable-line
          data-component="SocialToolbarItem"
          className={cn(theme.button, { xing: useColor }, 'fa', xing)}
          href={`https://www.xing.com/app/user?${qs.stringify({
            op: 'share',
            url,
            title: text,
          })}`}
          target="_blank"
          rel="noopener noreferrer"
          aria-label="Share on XING"
        />
      )}
      {zalo && [
        <a
          key="button"
          className={cn(theme.button, theme.zalo)}
          style={{
            backgroundImage:
              'url(https://stc.sp.zdn.vn/share/logo_white_s_2x_40.png)',
          }}
        >
          <div
            className={cn('zalo-share-button')}
            data-href={url}
            data-oaid="579745863508352884"
            data-layout="2"
            data-color="blue"
            data-customize={false}
          />
        </a>,
        <Script key="script" url="https://sp.zalo.me/plugins/sdk.js" />,
      ]}
    </Component>
  )
}

export default SocialToolbar
